@@ -10,4 +10,4 @@ class pr_gross_income(Variable):
     defined_for = StateCode.PR
     reference = "https://law.justia.com/codes/puerto-rico/title-thirteen/subtitle-17/part-ii/chapter-1005/subchapter-a/30101/"
 
-    adds = "gov.territories.pr.tax.income.gross_income.sources"
+    adds = ["pr_gross_income_person"]
