@@ -4,7 +4,7 @@ from policyengine_us.model_api import *
 class pr_gross_income_person(Variable):
     value_type = float
     entity = Person
-    label = "Puerto Rico gross income person"
+    label = "Puerto Rico gross income"
     unit = USD
     definition_period = YEAR
     defined_for = StateCode.PR
